@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT => qw(dicom_detect_file);
 Readonly::Scalar our $DCM_MAGIC => qw{DICM};
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Detect DICOM file.
 sub dicom_detect_file {
@@ -148,8 +148,17 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<DicomPack>,
-L<File::Find::Rule::Dicom>.
+=over
+
+=item L<File::Find::Rule::Dicom>
+
+Common rules for searching for DICOM things.
+
+=item L<Task::Dicom>
+
+Install the Dicom modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -163,10 +172,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2014-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
